xerr

package
v0.0.0-...-f8853a5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 1, 2026 License: BSD-3-Clause Imports: 2 Imported by: 0

Documentation

Overview

Package xerr provides the small set of error helpers this module needs.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Error

func Error(msg string) error

Error returns a new error with the given message.

func Errorf

func Errorf(format string, args ...any) error

Errorf returns a new formatted error.

func Wrap

func Wrap(err error, args ...any) error

Wrap annotates err with an optional message. A nil err returns nil so it can be used directly in a return statement.

func Wrapf

func Wrapf(err error, format string, args ...any) error

Wrapf annotates err with a formatted message. A nil err returns nil.

Types

This section is empty.

Jump to